//Source file: MailboxMessageStatus.java
//Date: November 2006
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.4.0

package org.csapi.jr.se.mmm;

/**
 * Defines the status of messages stored in the Mailbox.  
The first 4 status items are applicable to messages which have been received.  
The 5th status item refers to messages which have been created or put in the Mailbox and not yet sent.  
The remaining items are applicable to messages which have been sent from the mailbox, and for which a status is recorded and updated depending on any delivery reports which have been received.
 *
 */
public final class MailboxMessageStatus implements java.io.Serializable {

    private int _value;
    private static int _size = 11;
    private static MailboxMessageStatus[] _array = new MailboxMessageStatus[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MailboxMessageStatus(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The message received has been read
     */
    public static final int _MMM_RECEIVED_MSG_STATUS_READ =  0;

    /**
     * The message received has been read
     */
    public static final MailboxMessageStatus MMM_RECEIVED_MSG_STATUS_READ = new MailboxMessageStatus(_MMM_RECEIVED_MSG_STATUS_READ);

    /**
     * The message received has not been read
     */
    public static final int _MMM_RECEIVED_MSG_STATUS_UNREAD =  1;

    /**
     * The message received has not been read
     */
    public static final MailboxMessageStatus MMM_RECEIVED_MSG_STATUS_UNREAD = new MailboxMessageStatus(_MMM_RECEIVED_MSG_STATUS_UNREAD);

    /**
     * The message received has been forwarded
     */
    public static final int _MMM_RECEIVED_MSG_STATUS_FORWARDED =  2;

    /**
     * The message received has been forwarded
     */
    public static final MailboxMessageStatus MMM_RECEIVED_MSG_STATUS_FORWARDED = new MailboxMessageStatus(_MMM_RECEIVED_MSG_STATUS_FORWARDED);

    /**
     * The message received has been replied to
     */
    public static final int _MMM_RECEIVED_MSG_STATUS_REPLIED_TO =  3;

    /**
     * The message received has been replied to
     */
    public static final MailboxMessageStatus MMM_RECEIVED_MSG_STATUS_REPLIED_TO = new MailboxMessageStatus(_MMM_RECEIVED_MSG_STATUS_REPLIED_TO);

    /**
     * The message has been saved as a draft or is unsent
     */
    public static final int _MMM_DRAFT_MSG_STATUS_SAVED_OR_UNSENT =  4;

    /**
     * The message has been saved as a draft or is unsent
     */
    public static final MailboxMessageStatus MMM_DRAFT_MSG_STATUS_SAVED_OR_UNSENT = new MailboxMessageStatus(_MMM_DRAFT_MSG_STATUS_SAVED_OR_UNSENT);

    /**
     * The message has been sent.  No further information is available, because no delivery report was received, or none was requested
     */
    public static final int _MMM_SENT_MSG_STATUS_SENT =  5;

    /**
     * The message has been sent.  No further information is available, because no delivery report was received, or none was requested
     */
    public static final MailboxMessageStatus MMM_SENT_MSG_STATUS_SENT = new MailboxMessageStatus(_MMM_SENT_MSG_STATUS_SENT);

    /**
     * The message sent has been delivered
     */
    public static final int _MMM_SENT_MSG_STATUS_DELIVERED =  6;

    /**
     * The message sent has been delivered
     */
    public static final MailboxMessageStatus MMM_SENT_MSG_STATUS_DELIVERED = new MailboxMessageStatus(_MMM_SENT_MSG_STATUS_DELIVERED);

    /**
     * The message sent has been read
     */
    public static final int _MMM_SENT_MSG_STATUS_READ =  7;

    /**
     * The message sent has been read
     */
    public static final MailboxMessageStatus MMM_SENT_MSG_STATUS_READ = new MailboxMessageStatus(_MMM_SENT_MSG_STATUS_READ);

    /**
     * The message sent has been deleted without being read
     */
    public static final int _MMM_SENT_MSG_STATUS_DELETED_UNREAD =  8;

    /**
     * The message sent has been deleted without being read
     */
    public static final MailboxMessageStatus MMM_SENT_MSG_STATUS_DELETED_UNREAD = new MailboxMessageStatus(_MMM_SENT_MSG_STATUS_DELETED_UNREAD);

    /**
     * The message sent was undeliverable
     */
    public static final int _MMM_SENT_MSG_STATUS_NOT_DELIVERABLE =  9;

    /**
     * The message sent was undeliverable
     */
    public static final MailboxMessageStatus MMM_SENT_MSG_STATUS_NOT_DELIVERABLE = new MailboxMessageStatus(_MMM_SENT_MSG_STATUS_NOT_DELIVERABLE);

    /**
     * The message sent has expired before it was delivered
     */
    public static final int _MMM_SENT_MSG_STATUS_EXPIRED =  10;

    /**
     * The message sent has expired before it was delivered
     */
    public static final MailboxMessageStatus MMM_SENT_MSG_STATUS_EXPIRED = new MailboxMessageStatus(_MMM_SENT_MSG_STATUS_EXPIRED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MailboxMessageStatus object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MailboxMessageStatus object
     */
    public String getValueText() {
        switch (_value) {
            case _MMM_RECEIVED_MSG_STATUS_READ:
                return "MMM_RECEIVED_MSG_STATUS_READ";
            case _MMM_RECEIVED_MSG_STATUS_UNREAD:
                return "MMM_RECEIVED_MSG_STATUS_UNREAD";
            case _MMM_RECEIVED_MSG_STATUS_FORWARDED:
                return "MMM_RECEIVED_MSG_STATUS_FORWARDED";
            case _MMM_RECEIVED_MSG_STATUS_REPLIED_TO:
                return "MMM_RECEIVED_MSG_STATUS_REPLIED_TO";
            case _MMM_DRAFT_MSG_STATUS_SAVED_OR_UNSENT:
                return "MMM_DRAFT_MSG_STATUS_SAVED_OR_UNSENT";
            case _MMM_SENT_MSG_STATUS_SENT:
                return "MMM_SENT_MSG_STATUS_SENT";
            case _MMM_SENT_MSG_STATUS_DELIVERED:
                return "MMM_SENT_MSG_STATUS_DELIVERED";
            case _MMM_SENT_MSG_STATUS_READ:
                return "MMM_SENT_MSG_STATUS_READ";
            case _MMM_SENT_MSG_STATUS_DELETED_UNREAD:
                return "MMM_SENT_MSG_STATUS_DELETED_UNREAD";
            case _MMM_SENT_MSG_STATUS_NOT_DELIVERABLE:
                return "MMM_SENT_MSG_STATUS_NOT_DELIVERABLE";
            case _MMM_SENT_MSG_STATUS_EXPIRED:
                return "MMM_SENT_MSG_STATUS_EXPIRED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 10
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MailboxMessageStatus getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MailboxMessageStatus)) {
            return false;
        }
        MailboxMessageStatus mailboxMessageStatus = (MailboxMessageStatus) o; 
        if(!(this.getValue() == mailboxMessageStatus.getValue())) {
            return false;
        }
        if (this.hashCode() != mailboxMessageStatus.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MailboxMessageStatus

