//Source file: MessageHeaderFieldType.java
//Date: November 2006
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.4.0

package org.csapi.jr.se.mmm;

/**
 * Specifies the different types of header fields recognized. 
 *
 */
public final class MessageHeaderFieldType implements java.io.Serializable {

    private int _value;
    private static int _size = 24;
    private static MessageHeaderFieldType[] _array = new MessageHeaderFieldType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MessageHeaderFieldType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The origination date specifies the date and time at which the creator of the message indicated that the message was complete and ready to enter the mail delivery system.
     */
    public static final int _MESSAGE_DATE_SENT =  0;

    /**
     * The origination date specifies the date and time at which the creator of the message indicated that the message was complete and ready to enter the mail delivery system.
     */
    public static final MessageHeaderFieldType MESSAGE_DATE_SENT = new MessageHeaderFieldType(_MESSAGE_DATE_SENT);

    /**
     * Specifies the author(s) of the message,  that is, the mailbox address(es) of the person(s) or system(s) responsible for the writing of the message.
     */
    public static final int _MESSAGE_SENT_FROM =  1;

    /**
     * Specifies the author(s) of the message,  that is, the mailbox address(es) of the person(s) or system(s) responsible for the writing of the message.
     */
    public static final MessageHeaderFieldType MESSAGE_SENT_FROM = new MessageHeaderFieldType(_MESSAGE_SENT_FROM);

    /**
     * Specifies the mailbox address of the agent responsible for the actual transmission of the message.
     */
    public static final int _MESSAGE_SENDER =  2;

    /**
     * Specifies the mailbox address of the agent responsible for the actual transmission of the message.
     */
    public static final MessageHeaderFieldType MESSAGE_SENDER = new MessageHeaderFieldType(_MESSAGE_SENDER);

    /**
     * Indicates the mailbox adress(es) to which the author of the message suggests that replies be sent.
     */
    public static final int _MESSAGE_REPLY_TO =  3;

    /**
     * Indicates the mailbox adress(es) to which the author of the message suggests that replies be sent.
     */
    public static final MessageHeaderFieldType MESSAGE_REPLY_TO = new MessageHeaderFieldType(_MESSAGE_REPLY_TO);

    /**
     * Specifies the address(es) of the primary recipient(s) of the message.
     */
    public static final int _MESSAGE_SENT_TO =  4;

    /**
     * Specifies the address(es) of the primary recipient(s) of the message.
     */
    public static final MessageHeaderFieldType MESSAGE_SENT_TO = new MessageHeaderFieldType(_MESSAGE_SENT_TO);

    /**
     * Specifies the addresses of others who are to receive the message, though the content of the message may not be directed at them.
     */
    public static final int _MESSAGE_CC_TO =  5;

    /**
     * Specifies the addresses of others who are to receive the message, though the content of the message may not be directed at them.
     */
    public static final MessageHeaderFieldType MESSAGE_CC_TO = new MessageHeaderFieldType(_MESSAGE_CC_TO);

    /**
     * Specifies a unique message identifier that refers to a particular version of a particular message. This field has the same semantics as the RFC(2)822 "Message-ID:" field.
Note that this message ID can not be used on the messaging interface to address this specific message. See TpMessageDescription for more information.
     */
    public static final int _MESSAGE_RFC822_MESSAGE_ID =  7;

    /**
     * Specifies a unique message identifier that refers to a particular version of a particular message. This field has the same semantics as the RFC(2)822 "Message-ID:" field.
Note that this message ID can not be used on the messaging interface to address this specific message. See TpMessageDescription for more information.
     */
    public static final MessageHeaderFieldType MESSAGE_RFC822_MESSAGE_ID = new MessageHeaderFieldType(_MESSAGE_RFC822_MESSAGE_ID);

    /**
     * May be used to identify the message (or messages) to which the new message is a reply. The messages are referred by their RFC(2)822 Message-ID.
     */
    public static final int _MESSAGE_IN_REPLY_TO =  8;

    /**
     * May be used to identify the message (or messages) to which the new message is a reply. The messages are referred by their RFC(2)822 Message-ID.
     */
    public static final MessageHeaderFieldType MESSAGE_IN_REPLY_TO = new MessageHeaderFieldType(_MESSAGE_IN_REPLY_TO);

    /**
     * May be used to identify the message (or messages) with which this message forms a thread of conversation. The messages are referred by their RFC(2)822 Message-ID.
     */
    public static final int _MESSAGE_REFERENCES =  9;

    /**
     * May be used to identify the message (or messages) with which this message forms a thread of conversation. The messages are referred by their RFC(2)822 Message-ID.
     */
    public static final MessageHeaderFieldType MESSAGE_REFERENCES = new MessageHeaderFieldType(_MESSAGE_REFERENCES);

    /**
     * A short string identifying the topic of the message. 
     */
    public static final int _MESSAGE_SUBJECT =  10;

    /**
     * A short string identifying the topic of the message. 
     */
    public static final MessageHeaderFieldType MESSAGE_SUBJECT = new MessageHeaderFieldType(_MESSAGE_SUBJECT);

    /**
     * This field has the same semantics as the RFC(2)822 "Comments:" field.
     */
    public static final int _MESSAGE_COMMENTS =  11;

    /**
     * This field has the same semantics as the RFC(2)822 "Comments:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_COMMENTS = new MessageHeaderFieldType(_MESSAGE_COMMENTS);

    /**
     * This field has the same semantics as the RFC(2)822 "Keywords:" field.
     */
    public static final int _MESSAGE_KEYWORDS =  12;

    /**
     * This field has the same semantics as the RFC(2)822 "Keywords:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_KEYWORDS = new MessageHeaderFieldType(_MESSAGE_KEYWORDS);

    /**
     * All  trace fields like for example RFC(2)822 "Return-Path:" and "Received:" will be gathered under this flag.
     */
    public static final int _MESSAGE_TRACE_FIELD =  13;

    /**
     * All  trace fields like for example RFC(2)822 "Return-Path:" and "Received:" will be gathered under this flag.
     */
    public static final MessageHeaderFieldType MESSAGE_TRACE_FIELD = new MessageHeaderFieldType(_MESSAGE_TRACE_FIELD);

    /**
     * All  RFC(2)822 resent fields will be gathered under this flag.
     */
    public static final int _MESSAGE_RESENT_FIELD =  14;

    /**
     * All  RFC(2)822 resent fields will be gathered under this flag.
     */
    public static final MessageHeaderFieldType MESSAGE_RESENT_FIELD = new MessageHeaderFieldType(_MESSAGE_RESENT_FIELD);

    /**
     * Declare the version of the Internet message body format standard in use. This field has the same semantics as the RFC2045 "MIME-Version:" field.
     */
    public static final int _MESSAGE_MIME_VERSION =  15;

    /**
     * Declare the version of the Internet message body format standard in use. This field has the same semantics as the RFC2045 "MIME-Version:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_VERSION = new MessageHeaderFieldType(_MESSAGE_MIME_VERSION);

    /**
     * The Content-Type header field specifies the nature of the data in the body of an entity by giving media type and subtype identifiers, and by providing auxiliary information that may be required for certain media types. This field has the same semantics as the RFC2045 "Content-Type:" field.
     */
    public static final int _MESSAGE_MIME_CONTENT =  16;

    /**
     * The Content-Type header field specifies the nature of the data in the body of an entity by giving media type and subtype identifiers, and by providing auxiliary information that may be required for certain media types. This field has the same semantics as the RFC2045 "Content-Type:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_CONTENT = new MessageHeaderFieldType(_MESSAGE_MIME_CONTENT);

    /**
     * This field's value is a single token specifying the type of encoding. This field has the same semantics as the RFC2045 "Content-Transfer-Encoding:" field.
     */
    public static final int _MESSAGE_MIME_ENCODING =  17;

    /**
     * This field's value is a single token specifying the type of encoding. This field has the same semantics as the RFC2045 "Content-Transfer-Encoding:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_ENCODING = new MessageHeaderFieldType(_MESSAGE_MIME_ENCODING);

    /**
     * When present  uniquely identifyies a MIME entity. This field has the same semantics as the RFC2045 "Content-ID:" field.
     */
    public static final int _MESSAGE_MIME_ID =  18;

    /**
     * When present  uniquely identifyies a MIME entity. This field has the same semantics as the RFC2045 "Content-ID:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_ID = new MessageHeaderFieldType(_MESSAGE_MIME_ID);

    /**
     * Specifies some descriptive information about the MIME entity. This field has the same semantics as the RFC2045 "Content-Description:" field.
     */
    public static final int _MESSAGE_MIME_DESCRIPTION =  19;

    /**
     * Specifies some descriptive information about the MIME entity. This field has the same semantics as the RFC2045 "Content-Description:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_DESCRIPTION = new MessageHeaderFieldType(_MESSAGE_MIME_DESCRIPTION);

    /**
     * Specifies how the MIME entity shall be presented, inline or as an attachment. This field has the same semantics as the RFC2183 "Content-Disposition:" field.
     */
    public static final int _MESSAGE_MIME_DISPOSITION =  20;

    /**
     * Specifies how the MIME entity shall be presented, inline or as an attachment. This field has the same semantics as the RFC2183 "Content-Disposition:" field.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_DISPOSITION = new MessageHeaderFieldType(_MESSAGE_MIME_DISPOSITION);

    /**
     * Any RFC 822 header field which begins with the string "Content-" and does not match the description of the other MIME fields.
     */
    public static final int _MESSAGE_MIME_EXTENSION_FIELD =  21;

    /**
     * Any RFC 822 header field which begins with the string "Content-" and does not match the description of the other MIME fields.
     */
    public static final MessageHeaderFieldType MESSAGE_MIME_EXTENSION_FIELD = new MessageHeaderFieldType(_MESSAGE_MIME_EXTENSION_FIELD);

    /**
     * Any header field that does not match any of the of the other field types in this datatype.
     */
    public static final int _MESSAGE_EXTENSION_FIELD =  22;

    /**
     * Any header field that does not match any of the of the other field types in this datatype.
     */
    public static final MessageHeaderFieldType MESSAGE_EXTENSION_FIELD = new MessageHeaderFieldType(_MESSAGE_EXTENSION_FIELD);

    /**
     * The Priority of the message
     */
    public static final int _MESSAGE_PRIORITY =  23;

    /**
     * The Priority of the message
     */
    public static final MessageHeaderFieldType MESSAGE_PRIORITY = new MessageHeaderFieldType(_MESSAGE_PRIORITY);

    /**
     * Specifies addresses of recipients of the message whose addresses are not to be revealed to other recipients of the message.
     */
    public static final int _MESSAGE_BCC_TO =  6;

    /**
     * Specifies addresses of recipients of the message whose addresses are not to be revealed to other recipients of the message.
     */
    public static final MessageHeaderFieldType MESSAGE_BCC_TO = new MessageHeaderFieldType(_MESSAGE_BCC_TO);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MessageHeaderFieldType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MessageHeaderFieldType object
     */
    public String getValueText() {
        switch (_value) {
            case _MESSAGE_DATE_SENT:
                return "MESSAGE_DATE_SENT";
            case _MESSAGE_SENT_FROM:
                return "MESSAGE_SENT_FROM";
            case _MESSAGE_SENDER:
                return "MESSAGE_SENDER";
            case _MESSAGE_REPLY_TO:
                return "MESSAGE_REPLY_TO";
            case _MESSAGE_SENT_TO:
                return "MESSAGE_SENT_TO";
            case _MESSAGE_CC_TO:
                return "MESSAGE_CC_TO";
            case _MESSAGE_RFC822_MESSAGE_ID:
                return "MESSAGE_RFC822_MESSAGE_ID";
            case _MESSAGE_IN_REPLY_TO:
                return "MESSAGE_IN_REPLY_TO";
            case _MESSAGE_REFERENCES:
                return "MESSAGE_REFERENCES";
            case _MESSAGE_SUBJECT:
                return "MESSAGE_SUBJECT";
            case _MESSAGE_COMMENTS:
                return "MESSAGE_COMMENTS";
            case _MESSAGE_KEYWORDS:
                return "MESSAGE_KEYWORDS";
            case _MESSAGE_TRACE_FIELD:
                return "MESSAGE_TRACE_FIELD";
            case _MESSAGE_RESENT_FIELD:
                return "MESSAGE_RESENT_FIELD";
            case _MESSAGE_MIME_VERSION:
                return "MESSAGE_MIME_VERSION";
            case _MESSAGE_MIME_CONTENT:
                return "MESSAGE_MIME_CONTENT";
            case _MESSAGE_MIME_ENCODING:
                return "MESSAGE_MIME_ENCODING";
            case _MESSAGE_MIME_ID:
                return "MESSAGE_MIME_ID";
            case _MESSAGE_MIME_DESCRIPTION:
                return "MESSAGE_MIME_DESCRIPTION";
            case _MESSAGE_MIME_DISPOSITION:
                return "MESSAGE_MIME_DISPOSITION";
            case _MESSAGE_MIME_EXTENSION_FIELD:
                return "MESSAGE_MIME_EXTENSION_FIELD";
            case _MESSAGE_EXTENSION_FIELD:
                return "MESSAGE_EXTENSION_FIELD";
            case _MESSAGE_PRIORITY:
                return "MESSAGE_PRIORITY";
            case _MESSAGE_BCC_TO:
                return "MESSAGE_BCC_TO";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 23
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MessageHeaderFieldType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MessageHeaderFieldType)) {
            return false;
        }
        MessageHeaderFieldType messageHeaderFieldType = (MessageHeaderFieldType) o; 
        if(!(this.getValue() == messageHeaderFieldType.getValue())) {
            return false;
        }
        if (this.hashCode() != messageHeaderFieldType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MessageHeaderFieldType

