//Source file: MessagePriority.java
//Date: November 2006
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.4.0

package org.csapi.jr.se.mmm;

/**
 * Defines the priority of a message.
 *
 */
public final class MessagePriority implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static MessagePriority[] _array = new MessagePriority[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MessagePriority(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined/Normal
     */
    public static final int _MMM_MESSAGE_PRIORITY_UNDEFINED =  0;

    /**
     * Undefined/Normal
     */
    public static final MessagePriority MMM_MESSAGE_PRIORITY_UNDEFINED = new MessagePriority(_MMM_MESSAGE_PRIORITY_UNDEFINED);

    /**
     * High priority
     */
    public static final int _MMM_MESSAGE_PRIORITY_HIGH =  1;

    /**
     * High priority
     */
    public static final MessagePriority MMM_MESSAGE_PRIORITY_HIGH = new MessagePriority(_MMM_MESSAGE_PRIORITY_HIGH);

    /**
     * Low priority
     */
    public static final int _MMM_MESSAGE_PRIORITY_LOW =  2;

    /**
     * Low priority
     */
    public static final MessagePriority MMM_MESSAGE_PRIORITY_LOW = new MessagePriority(_MMM_MESSAGE_PRIORITY_LOW);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MessagePriority object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MessagePriority object
     */
    public String getValueText() {
        switch (_value) {
            case _MMM_MESSAGE_PRIORITY_UNDEFINED:
                return "MMM_MESSAGE_PRIORITY_UNDEFINED";
            case _MMM_MESSAGE_PRIORITY_HIGH:
                return "MMM_MESSAGE_PRIORITY_HIGH";
            case _MMM_MESSAGE_PRIORITY_LOW:
                return "MMM_MESSAGE_PRIORITY_LOW";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MessagePriority getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MessagePriority)) {
            return false;
        }
        MessagePriority messagePriority = (MessagePriority) o; 
        if(!(this.getValue() == messagePriority.getValue())) {
            return false;
        }
        if (this.hashCode() != messagePriority.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MessagePriority

