//Source file: MessageTreatmentType.java
//Date: November 2006
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.4.0

package org.csapi.jr.se.mmm;

/**
 * Specifies the various types of message treatment which the application may request when sending a message.
 *
 */
public final class MessageTreatmentType implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static MessageTreatmentType[] _array = new MessageTreatmentType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MessageTreatmentType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _MMM_TREATMENT_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final MessageTreatmentType MMM_TREATMENT_UNDEFINED = new MessageTreatmentType(_MMM_TREATMENT_UNDEFINED);

    /**
     * Request various delivery notifications
     */
    public static final int _MMM_TREATMENT_REPORT_REQUESTED =  1;

    /**
     * Request various delivery notifications
     */
    public static final MessageTreatmentType MMM_TREATMENT_REPORT_REQUESTED = new MessageTreatmentType(_MMM_TREATMENT_REPORT_REQUESTED);

    /**
     * A Billing Identifier/Charging Code  that can be used to indicate how the costs for this transaction shall be charged.
     */
    public static final int _MMM_TREATMENT_BILLING_ID =  2;

    /**
     * A Billing Identifier/Charging Code  that can be used to indicate how the costs for this transaction shall be charged.
     */
    public static final MessageTreatmentType MMM_TREATMENT_BILLING_ID = new MessageTreatmentType(_MMM_TREATMENT_BILLING_ID);

    /**
     * Specifies whether the message shall be delivered instantly or at some specified time.
     */
    public static final int _MMM_TREATMENT_DELIVERY_TIME =  3;

    /**
     * Specifies whether the message shall be delivered instantly or at some specified time.
     */
    public static final MessageTreatmentType MMM_TREATMENT_DELIVERY_TIME = new MessageTreatmentType(_MMM_TREATMENT_DELIVERY_TIME);

    /**
     * Specifies the time within which the message keeps its validity. When the message is not delivered before the validity time passes, the message is dropped by the messaging system.
     */
    public static final int _MMM_TREATMENT_VALIDITY_TIME =  4;

    /**
     * Specifies the time within which the message keeps its validity. When the message is not delivered before the validity time passes, the message is dropped by the messaging system.
     */
    public static final MessageTreatmentType MMM_TREATMENT_VALIDITY_TIME = new MessageTreatmentType(_MMM_TREATMENT_VALIDITY_TIME);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MessageTreatmentType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MessageTreatmentType object
     */
    public String getValueText() {
        switch (_value) {
            case _MMM_TREATMENT_UNDEFINED:
                return "MMM_TREATMENT_UNDEFINED";
            case _MMM_TREATMENT_REPORT_REQUESTED:
                return "MMM_TREATMENT_REPORT_REQUESTED";
            case _MMM_TREATMENT_BILLING_ID:
                return "MMM_TREATMENT_BILLING_ID";
            case _MMM_TREATMENT_DELIVERY_TIME:
                return "MMM_TREATMENT_DELIVERY_TIME";
            case _MMM_TREATMENT_VALIDITY_TIME:
                return "MMM_TREATMENT_VALIDITY_TIME";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MessageTreatmentType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MessageTreatmentType)) {
            return false;
        }
        MessageTreatmentType messageTreatmentType = (MessageTreatmentType) o; 
        if(!(this.getValue() == messageTreatmentType.getValue())) {
            return false;
        }
        if (this.hashCode() != messageTreatmentType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MessageTreatmentType

