//Source file: MessagingEventName.java
//Date: November 2006
//Multi Media Messaging for for 3GPP TS 29.198-15 V6.4.0

package org.csapi.jr.se.mmm;

/**
 * Defines the names of the messaging events which can be notified. 
 *
 */
public final class MessagingEventName implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static MessagingEventName[] _array = new MessagingEventName[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private MessagingEventName(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _EVENT_MSG_NAME_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final MessagingEventName EVENT_MSG_NAME_UNDEFINED = new MessagingEventName(_EVENT_MSG_NAME_UNDEFINED);

    /**
     * New message arrived in the mailbox.  The message contents are not requested/delivered - the message can be retrieved from the mailbox.
     */
    public static final int _EVENT_MSG_NEW_MAILBOX_MESSAGE_ARRIVED =  1;

    /**
     * New message arrived in the mailbox.  The message contents are not requested/delivered - the message can be retrieved from the mailbox.
     */
    public static final MessagingEventName EVENT_MSG_NEW_MAILBOX_MESSAGE_ARRIVED = new MessagingEventName(_EVENT_MSG_NEW_MAILBOX_MESSAGE_ARRIVED);

    /**
     * New message arrived.  The Message contents are requested/delivered with this event.
     */
    public static final int _EVENT_MSG_NEW_MESSAGE_ARRIVED =  2;

    /**
     * New message arrived.  The Message contents are requested/delivered with this event.
     */
    public static final MessagingEventName EVENT_MSG_NEW_MESSAGE_ARRIVED = new MessagingEventName(_EVENT_MSG_NEW_MESSAGE_ARRIVED);

    /**
     * New message status report arrived as a result of using the sending with notification functionality. The status contents are requested/delivered with this event.
     */
    public static final int _EVENT_MSG_STATUS_REPORT_ARRIVED =  3;

    /**
     * New message status report arrived as a result of using the sending with notification functionality. The status contents are requested/delivered with this event.
     */
    public static final MessagingEventName EVENT_MSG_STATUS_REPORT_ARRIVED = new MessagingEventName(_EVENT_MSG_STATUS_REPORT_ARRIVED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved MessagingEventName object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the MessagingEventName object
     */
    public String getValueText() {
        switch (_value) {
            case _EVENT_MSG_NAME_UNDEFINED:
                return "EVENT_MSG_NAME_UNDEFINED";
            case _EVENT_MSG_NEW_MAILBOX_MESSAGE_ARRIVED:
                return "EVENT_MSG_NEW_MAILBOX_MESSAGE_ARRIVED";
            case _EVENT_MSG_NEW_MESSAGE_ARRIVED:
                return "EVENT_MSG_NEW_MESSAGE_ARRIVED";
            case _EVENT_MSG_STATUS_REPORT_ARRIVED:
                return "EVENT_MSG_STATUS_REPORT_ARRIVED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static MessagingEventName getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MessagingEventName)) {
            return false;
        }
        MessagingEventName messagingEventName = (MessagingEventName) o; 
        if(!(this.getValue() == messagingEventName.getValue())) {
            return false;
        }
        if (this.hashCode() != messagingEventName.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MessagingEventName

